# How to cite phono3py

## Citation of phono3py

If you have used phono3py, please cite the following article:

- "Distributions of phonon lifetimes in Brillouin zones",
  Atsushi Togo, Laurent Chaput, and Isao Tanaka, Phys. Rev. B, **91**, 094306 (2015)

  ```
  @article{phono3py,
    title = {Distributions of phonon lifetimes in Brillouin zones},
    author = {Togo, Atsushi and Chaput, Laurent and Tanaka, Isao},
    journal = {Phys. Rev. B},
    volume = {91},
    issue = {9},
    pages = {094306},
    numpages = {31},
    year = {2015},
    month = {Mar},
    publisher = {American Physical Society},
    doi = {10.1103/PhysRevB.91.094306},
  }
  ```

(citation_direct_solution_lbte)=
## Citation of direct solution of LBTE (`--lbte`)

If you have used direct solution of LBTE in phono3py, please cite the
following article:

- "Direct Solution to the Linearized Phonon Boltzmann Equation"
  Laurent Chaput, Phys. Rev. Lett., **110**, 265506 (2013)

  ```
  @article{PhysRevLett.110.265506,
    title = {Direct Solution to the Linearized Phonon Boltzmann Equation},
    author = {Chaput, Laurent},
    journal = {Phys. Rev. Lett.},
    volume = {110},
    issue = {26},
    pages = {265506},
    numpages = {5},
    year = {2013},
    month = {Jun},
    publisher = {American Physical Society},
    doi = {10.1103/PhysRevLett.110.265506},
    url = {https://link.aps.org/doi/10.1103/PhysRevLett.110.265506}
  }
  ```
